@@ -6,7 +6,7 @@ use 5.014;
 
 no if $] >= 5.018, warnings => 'experimental::smartmatch';
 
-our $VERSION = '1.65';
+our $VERSION = '1.66';
 
 use Carp qw(confess cluck);
 use DateTime;
@@ -455,10 +455,12 @@ sub get_station {
 
 	# @seen holds station IDs which were already seen during recursive
 	# 'meta' descent. This avoids infinite loops of 'meta' references.
-	# As Norddeich and Norddeich Mole are illegaly coupled in the backend
-	# (they are different stations with different departure times), we pre-seed
-	# @seen with their eva IDs.
-	my @seen = ( 8007768, 8004449 );
+	# Additionally, we use it to skip stations shat should not be referenced.
+	# This includes Norddeich / Norddeich Mole (different stations commonly used
+	# by identical trains with different departure times), and Essen-Dellwig /
+	# Essen-Dellwig Ost (different stations used by different trains, but with
+	# identical platform numbers).
+	my @seen = ( 8007768, 8004449, 8001903, 8001904 );
 
 	while ( @queue and $iter_depth < 12 ) {
 		my $station = shift(@queue);
@@ -962,7 +964,7 @@ Non-blocking variant (EXPERIMENTAL):
 
 =head1 VERSION
 
-version 1.65
+version 1.66
 
 =head1 DESCRIPTION
 
